####################################################

#R Version info


# $platform
# [1] "x86_64-w64-mingw32"
# 
# $arch
# [1] "x86_64"
# 
# $os
# [1] "mingw32"
# 
# $system
# [1] "x86_64, mingw32"
# 
# $status
# [1] ""
# 
# $major
# [1] "3"
# 
# $minor
# [1] "2.5"
# 
# $year
# [1] "2016"
# 
# $month
# [1] "04"
# 
# $day
# [1] "14"
# 
# $`svn rev`
# [1] "70478"
# 
# $language
# [1] "R"
# 
# $version.string
# [1] "R version 3.2.5 (2016-04-14)"
# 
# $nickname
# [1] "Very, Very Secure Dishes"

####################################################
#setwd(...)

## Load packages

library(mgcv)
library(ggplot2)
library(cowplot)
library(forecast)
library(rgdal)
library(raster)
library(lattice)
library(RColorBrewer)
library(car)

####################################################

## Read data
mya=read.csv("Mya_Survey_CB.csv",header=T)
tag.comp=read.csv("Tag dens comp.csv",header=T)
mya.comp=read.csv("Mya dens comp.csv",header=T)
lengths.suction.dredge=read.csv("length comp.csv",header=T)
lengths.mya.tag=read.csv("lengths.csv",header=T)
susq_flow=read.csv("Susquehanna_river_flow.csv",header=TRUE)
temperatures=read.csv("temp.csv",header=TRUE)
recruit_time_series=read.csv("recruit_timeseries.csv")
cb_coastline = readOGR("chesapeakebay.shp")

####################################################

#Store each column as a variable

region=mya$Region
river=mya$River
site=mya$Site
season=mya$Season
year=as.factor(mya$Year)
day=mya$Date
lat=jitter((mya$Lat-mean(na.omit(mya$Lat)))/sd(na.omit(mya$Lat)),factor=0.1) #Z-score transformed, and then jittered to overcome repeats for modeling
lon=jitter((mya$Lon-mean(na.omit(mya$Lon)))/sd(na.omit(mya$Lon)),factor=0.1) #Z-score transformed, and then jittered to overcome repeats for modeling
temp=mya$Temp
sal=mya$Sal
do=mya$DO
rays=mya$Rays/100 #To correct for transect area
crabs=mya$Crabs/40 #To correct for transect area
fish=mya$Fish/40 #To correct for transect area
sb=mya$Sb
mya$tag.PA=0
mya$tag.PA[mya$T.No>0]=1
mya$mya.PA=0
mya$mya.PA[mya$M.No>0]=1
mya.PA=mya$mya.PA
tag.PA=mya$tag.PA
M.length=mya$M.Mean.length
T.length=mya$T.Mean.length
M.mean.dis=mya$M.Mean.Dis
T.mean.dis=mya$T.Mean.Dis
M.max.dis=mya$M.Max.Dis
T.max.dis=mya$T.Max.Dis
M.Prop.Dis=mya$M.Prop.Dis
T.Prop.Dis=mya$T.Prop.Dis

#Note: Statistical output will vary slightly due to jittering 
#in the latitude and longitude, and bootstrapping techniques.
####################################################

#Producing corrected lower Bay densities based on paired 
#suctions-dredges in the upper Chesapeake Bay


# Mya arenaria densities calculated using suction sampling 
# were 3.58 times higher than those calculated from hydraulic 
# dredge samples (R2 = 0.95; Supplementary Fig. 1a)

lm.mya.comp=lm(Suc.dens~Dens,data=mya.comp)
a=summary(lm.mya.comp)
a
mya.dens.seq=seq(min(mya.comp$Dens),max(mya.comp$Dens),0.1)
mya.preds=a$coefficients[1,1]+(a$coefficients[2,1]*mya.dens.seq)

# Suction sample densities for M. arenaria were reduced by a 
# factor of 3.58 to allow both data sets to be analyzed together

M.Corr.Dens=round(mya$M.Dens[mya$Region=="LB"]/a$coefficients[2,1],2)
mya$M.Corr.Dens[mya$Region=="LB"]=M.Corr.Dens
mya$M.Corr.Dens[mya$Region=="UB"]=mya$M.Dens[mya$Region=="UB"]
M.dens=mya$M.Corr.Dens

mya.comp2=mya.comp[-8,]
lm.mya.comp2=lm(Suc.dens~Dens,data=mya.comp2)
b=summary(lm.mya.comp2)
b

#
z1=(a$coefficients[2,1]-b$coefficients[2,1])/sqrt(a$coefficients[2,2]^2+b$coefficients[2,2]^2)
# 1.386778
p1=2*pnorm(-abs(z1))
# 0.1655096

# Densities calculated for T. plebeius using both methods were 
# in close agreement (slope = 1.10, R2 = 0.90; Supplementary Fig. 1b)

lm.tag.comp=lm(Suc.dens~Dens,data=tag.comp)
c=summary(lm.tag.comp)
c
tag.dens.seq=seq(min(tag.comp$Dens),max(tag.comp$Dens),0.1)
tag.preds=c$coefficients[1,1]+(c$coefficients[2,1]*tag.dens.seq)

# Raw data sets were combined for analyses

T.dens=mya$T.Dens

tag.comp2=tag.comp[-2,]
lm.tag.comp=lm(Suc.dens~Dens,data=tag.comp2)
d=summary(lm.tag.comp)
d

z2=(c$coefficients[2,1]-d$coefficients[2,1])/sqrt(c$coefficients[2,2]^2+d$coefficients[2,2]^2)
# 1.356239
p2=2*pnorm(-abs(z2))
# 0.1750232

#Produce Supplemental Figure 1

jpeg("dens comp.jpg", width = 4, height = 6,units="in",res=300)

txt.a=expression(paste("a."))
txt.b=expression(paste("b."))
txt.eq.mya=paste("y = ",round(a$coefficients[1,1],digits=2)," + ",round(a$coefficients[2,1],digits=2)," x",sep="")
txt.eq.tag=paste("y = ",round(b$coefficients[1,1],digits=2)," + ",round(b$coefficients[2,1],digits=2)," x",sep="")

par(mfrow=c(2,1),mar=c(4,4.1,1,1))

plot(mya.comp$Dens,mya.comp$Suc.dens,main="",ylab="Density from suction",xlab="Density from dredge",cex.axis=1.2,cex.lab=1.2)
lines(mya.dens.seq,mya.preds,lwd=2)
text(x=quantile(mya.comp$Dens,probs=c(0.932)),y=quantile(mya.comp$Suc.dens,probs=c(0.7)),labels=txt.eq.mya,pos=4,cex=1.2)
text(txt.a,x=0.5,y=37,cex=1.2)

plot(tag.comp$Dens,tag.comp$Suc.dens,main="",ylab="Density from suction",xlab="Density from dredge",cex.axis=1.2,cex.lab=1.2)
lines(tag.dens.seq,tag.preds,lwd=2)
text(x=quantile(tag.comp$Dens,probs=c(0.90)),y=quantile(tag.comp$Suc.dens,probs=c(0.6)),labels=txt.eq.tag,pos=4,cex=1.2)
text(txt.b,x=5/4,y=33,cex=1.2)

dev.off()

#Compare size (length) of Mya arenaria captured in suction 
#samples versus those caught in hydraulic dredge samples

mya.lengths.suction=lengths.suction.dredge$suction

# Suction samples appeared to collect more small and large 
# Mya arenaria (mean 42.33 mm, SD 13.73 mm; Supplementary 
# Fig. 2a) than dredge sampling (mean 40.22 mm, SD 5.42 mm; 
# Supplementary Fig. 2b)

mean(na.omit(mya.lengths.suction))
sd(na.omit(mya.lengths.suction))

mya.lengths.dredge=lengths.suction.dredge$dredge

mean(na.omit(mya.lengths.dredge))
sd(na.omit(mya.lengths.dredge))

#Produce Supplementary Figure 2

jpeg("length hist.jpg", width = 4, height = 6,units="in",res=300)

par(mfrow=c(2,1),mar=c(4,4.1,1,1))
hist(na.omit(mya.lengths.suction),freq=FALSE,breaks=seq(10,80,by=5),xlab="Length (mm)",main="",cex.axis=1.2,cex.lab=1.2)
text(txt.a,x=12,y=0.057,cex=1.2)
box()
hist(na.omit(mya.lengths.dredge),freq=FALSE,breaks=seq(10,80,by=5),xlab="Length (mm)",main="",cex.axis=1.2,cex.lab=1.2)
text(txt.b,x=12,y=0.08,cex=1.2)
box()
dev.off()

####################################################

#Looking at correlation between variables

predictor.mat=cbind(temp,sal,do,rays,crabs,fish)

predictor.mat=na.omit(predictor.mat)
head(predictor.mat)

jpeg("splom.jpg", width = 7, height = 8,units="in",res=300)

# Supplemental Figure 3

# There was no evidence of multicollinearity; all variable 
# combinations had Pearson correlation coefficients ??? 0.8 
# (Supplementary Figure 3; Berry & Feldman 1985).

splom(~predictor.mat, lower.panel = panel.splom,
      upper.panel = function(x, y, ...) {
        panel.fill(col = brewer.pal(9, "RdBu")[ round(cor(x, y) * 4 + 5)])
        cpl <- current.panel.limits()
        panel.text(mean(cpl$xlim), mean(cpl$ylim), round(cor(x, y),2), font=2)
      },
      
      scales = list(x = list( draw = TRUE, cex=0.1)), type = c("g", "p", "smooth"),layout =           c(1, 1), pscales=0, pch=".",
      ylab="Correlation coefficient")

dev.off()

####################################################

#Creating functions that will be used throughout the script

## Create function for bootstrapping

boots=function(response,pred,lower,higher)
{
  resp1=response[pred==lower|pred==higher]
  pred1=pred[pred==lower|pred==higher]
  calc.s=mean(resp1[pred1==lower])-mean(resp1[pred1==higher])
  l.g1=length(resp1[pred1==lower])
  l.total=length(resp1)
  
  rand.s=NULL
  #Another way to make a blank data set to put bootstrapped means
  n=9999
  i=1 
  for(i in 1:n)
  {
    samp=sample(resp1, size = l.total, replace = T)
    rand.s[i]=mean(samp[1:l.g1])-mean(samp[(l.g1+1):l.total])
  }
  
  sim.diffs=length(rand.s[rand.s<=calc.s])
  sim.diffs
  
  pvalue=(sim.diffs+1)/(n+1)
  return(pvalue)
}

## Create function to calculate Cohen's d for effect size
ES=function(a,b)
{
  effect.size=(mean(a)-mean(b))/sqrt(((length(a)-1)*var(a))+((length(b)-1)*var(b))/(length(a)+length(b)-2))
  return(effect.size)
}

#Function to bootstrap pooled means

boots_pooled=function(lower,higher,lower.n,higher.n)
{
  lower=na.omit(lower)
  higher=na.omit(higher)
  lower.n=na.omit(lower.n)
  higher.n=na.omit(higher.n)
  
  pooled.mean.lower=sum(lower*lower.n)/sum(lower.n)
  pooled.mean.higher=sum(higher*higher.n)/sum(higher.n)
  
  calc.s=pooled.mean.higher-pooled.mean.lower
  
  l.g1=length(lower)
  resp1=c(lower,higher)
  n1=c(lower.n,higher.n)
  l.total=length(resp1)
  
  rand.s=NULL
  n=9999
  i=1 
  for(i in 1:n)
  {
    samp=c(1:l.total)
    rand.samp=matrix(NA,nrow=l.total,ncol=3)
    rand.samp[,1]=sample(samp, size = l.total, replace = T)
    rand.samp[,2]=resp1[rand.samp[,1]]
    rand.samp[,3]=n1[rand.samp[,1]]
    rand.s[i]=(sum(rand.samp[1:l.g1,2]*rand.samp[1:l.g1,3])/sum(rand.samp[1:l.g1,3]))-(sum(rand.samp[(l.g1+1):l.total,2]*rand.samp[(l.g1+1):l.total,3])/sum(rand.samp[(l.g1+1):l.total,3]))
    
  }
  
  sim.diffs=length(rand.s[rand.s>=calc.s])
  sim.diffs
  
  pvalue=(sim.diffs+1)/(n+1)
  return(pvalue)
}

#Function to calculate Cohen's d for effect size for pooled means

ES_pooled=function(a,b,a.n,b.n,a.sd,b.sd)
{
  a=na.omit(a)
  b=na.omit(b)
  a.n=na.omit(a.n)
  b.n=na.omit(b.n)
  a.sd=na.omit(a.sd)
  b.sd=na.omit(b.sd)
  mean.a=sum(a*a.n)/sum(a.n)
  mean.b=sum(b*b.n)/sum(a.n)
  length.a=sum(a.n)
  length.b=sum(a.n)
  var.a=(sum((a.n-1)*a.sd)/(sum(a.n)-3))^2
  var.b=(sum((b.n-1)*b.sd)/(sum(b.n)-3))^2
  effect.size=(mean.a-mean.b)/sqrt(((length.a-1)*var.a)+((length.b-1)*var.b)/(length.a+length.b-2))
  
  return(effect.size)
}

# Function that summarizes data

# Gives count, mean, standard deviation, standard error of the mean, and confidence interval (default 95%).
# data: a data frame.
# measurevar: the name of a column that contains the variable to be summariezed
# groupvars: a vector containing names of columns that contain grouping variables
# na.rm: a boolean that indicates whether to ignore NA's
# conf.interval: the percent range of the confidence interval (default is 95%)
summarySE <- function(data=NULL, measurevar, groupvars=NULL, na.rm=FALSE,
                      conf.interval=.95, .drop=TRUE) {
  library(plyr)
  # New version of length which can handle NA's: if na.rm==T, don't count them
  length2 <- function (x, na.rm=FALSE) {
    if (na.rm) sum(!is.na(x))
    else       length(x)
  }
  
  # This does the summary. For each group's data frame, return a vector with
  # N, mean, and sd
  datac <- ddply(data, groupvars, .drop=.drop,
                 .fun = function(xx, col) {
                   c(N    = length2(xx[[col]], na.rm=na.rm),
                     mean = mean   (xx[[col]], na.rm=na.rm),
                     sd   = sd     (xx[[col]], na.rm=na.rm),
                     max   = max     (xx[[col]], na.rm=na.rm)
                   )
                 },
                 measurevar
  )
  
  # Rename the "mean" column    
  datac <- rename(datac, c("mean" = measurevar))
  
  datac$se <- datac$sd / sqrt(datac$N)  # Calculate standard error of the mean
  
  # Confidence interval multiplier for standard error
  # Calculate t-statistic for confidence interval: 
  # e.g., if conf.interval is .95, use .975 (above/below), and use df=N-1
  ciMult <- qt(conf.interval/2 + .5, datac$N-1)
  datac$ci <- datac$se * ciMult
  
  return(datac)
}

# Multiple plot function
#
# ggplot objects can be passed in ..., or to plotlist (as a list of ggplot objects)
# - cols:   Number of columns in layout
# - layout: A matrix specifying the layout. If present, 'cols' is ignored.
#
# If the layout is something like matrix(c(1,2,3,3), nrow=2, byrow=TRUE),
# then plot 1 will go in the upper left, 2 will go in the upper right, and
# 3 will go all the way across the bottom.
#
multiplot <- function(..., plotlist=NULL, file, cols=1, layout=NULL) {
  library(grid)
  
  # Make a list from the ... arguments and plotlist
  plots <- c(list(...), plotlist)
  
  numPlots = length(plots)
  
  # If layout is NULL, then use 'cols' to determine layout
  if (is.null(layout)) {
    # Make the panel
    # ncol: Number of columns of plots
    # nrow: Number of rows needed, calculated from # of cols
    layout <- matrix(seq(1, cols * ceiling(numPlots/cols)),
                     ncol = cols, nrow = ceiling(numPlots/cols))
  }
  
  if (numPlots==1) {
    print(plots[[1]])
    
  } else {
    # Set up the page
    grid.newpage()
    pushViewport(viewport(layout = grid.layout(nrow(layout), ncol(layout))))
    
    # Make each plot, in the correct location
    for (i in 1:numPlots) {
      # Get the i,j matrix positions of the regions that contain this subplot
      matchidx <- as.data.frame(which(layout == i, arr.ind = TRUE))
      
      print(plots[[i]], vp = viewport(layout.pos.row = matchidx$row,
                                      layout.pos.col = matchidx$col))
    }
  }
}

# Format decimals in shortest form possible for axes labels

fmt_dcimals <- function(decimals=0){
  function(x) format(x,nsmall = decimals,scientific = FALSE)
}

####################################################

## Results

####################################################

###Environmental variables

# Table 1

# Getting mean lats and lons for each site

loc.sites=cbind(tapply(na.omit(mya$Lat),mya$Site[!is.na(mya$Lat)],FUN=mean),tapply(na.omit(mya$Long),mya$Site[!is.na(mya$Long)],FUN=mean))
loc.sites=loc.sites[order(loc.sites[,1]),]

# Getting mean temp, sal, and DO for each site

temp.sites=cbind(round(tapply(na.omit(temp),site[!is.na(temp)],FUN=mean),2),
round(tapply(na.omit(temp),site[!is.na(temp)],FUN=sd),2),
round(tapply(na.omit(lat),site[!is.na(lat)],FUN=mean),2))

temp.sites=data.frame("sites"=names(temp.sites[order(temp.sites[,3]),][,1]),
                      "mean"=paste(unname(temp.sites[order(temp.sites[,3]),][,1])," (",unname(temp.sites[order(temp.sites[,3]),][,2]),")",sep=""))

sal.sites=cbind(round(tapply(na.omit(sal),site[!is.na(sal)],FUN=mean),2),
                 round(tapply(na.omit(sal),site[!is.na(sal)],FUN=sd),2),
                 round(tapply(na.omit(lat),site[!is.na(lat)],FUN=mean),2))

sal.sites=data.frame("sites"=names(sal.sites[order(sal.sites[,3]),][,1]),
                      "mean"=paste(unname(sal.sites[order(sal.sites[,3]),][,1])," (",unname(sal.sites[order(sal.sites[,3]),][,2]),")",sep=""))


do.sites=cbind(round(tapply(na.omit(do),site[!is.na(do)],FUN=mean),2),
                round(tapply(na.omit(do),site[!is.na(do)],FUN=sd),2),
                round(tapply(na.omit(lat),site[!is.na(lat)],FUN=mean),2))

do.sites=data.frame("sites"=names(do.sites[order(do.sites[,3]),][,1]),
                     "mean"=paste(unname(do.sites[order(do.sites[,3]),][,1])," (",unname(do.sites[order(do.sites[,3]),][,2]),")",sep=""))


#Temperature over the course of the survey (fall 2011 - 
#summer 2013) ranged 12.6 C - 33.3 C. 

min(na.omit(temp))
#12.6
unique(site[temp==min(na.omit(temp))])
#Mobjack 3

max(na.omit(temp))
#33.3
unique(site[temp==max(na.omit(temp))])
#Mobjack 2

#Temperatures exceeding 28 C and 30 C were observed 
#for 23.7% and 6.5% of all samples collected, respectively. 

length(na.omit(temp[temp>=28]))/length(na.omit(temp))
#0.236715
length(na.omit(temp[temp>=30]))/length(na.omit(temp))
#0.06531729

# Salinity ranged from 5.3 psu in the upper York River site 
# to 25.7 psu in the Lynnhaven Bay sites. 

min(na.omit(sal))
#5.3
unique(site[sal==min(na.omit(sal))])
#Poropotank

max(na.omit(sal))
#25.7
unique(site[sal==max(na.omit(sal))])
#Pleasure House Creek

# The minimum dissolved oxygen level observed was 3.3 mg L-1 
# in Mobjack Bay, though the site means ranged 6.50 mg L-1 - 
# 9.35 mg L-1 (Table 1). 

min(na.omit(do))
#3.3
unique(site[do==min(na.omit(do))])
#Mobjack 1

max(na.omit(do))
#16.4
unique(site[do==max(na.omit(do))])
#Purtan

do.sites

### Predators

mean(na.omit(fish))
#0.4683989
sd(na.omit(fish))
#1.180058

max(na.omit(fish))
#9.375
unique(site[fish==max(na.omit(fish))])
#Mobjack 2

length(na.omit(fish[fish>0]))/length(na.omit(fish))
#0.8302469

mean(na.omit(rays))
#0.0435
sd(na.omit(rays))
#0.0882796

max(na.omit(rays))
#0.46
unique(site[rays==max(na.omit(rays))])
#King's Creek

length(na.omit(rays[rays>0]))/length(na.omit(rays))
#0.4

mean(na.omit(crabs))
#0.3604454
sd(na.omit(crabs))
#0.9712663

max(na.omit(crabs))
#7.25
unique(site[crabs==max(na.omit(crabs))])
#Pleasure House Creek

length(na.omit(crabs[crabs>0]))/length(na.omit(crabs))
#0.7471264

####################################################

### Spatial trends

#Densities of M. arenaria were 2.75 times higher at sites 
#in the lower Bay than at sites in the upper Bay (p = 0.02, 
#d = 0.01, Fig. 2a). 

mean(M.dens[region=="LB"])/mean(M.dens[region=="UB"])
#2.750353
boots(response=M.dens,pred=region,higher="LB",lower="UB")
#0.0205
ES(M.dens[region=="LB"],M.dens[region=="UB"])
#0.008370264

#The maximum density observed was 53.33 m-2 M. arenaria 
#near the mouth of the York River, VA, in spring 2012. 

max(M.dens)
site[M.dens==max(M.dens)]
year[M.dens==max(M.dens)]
season[M.dens==max(M.dens)]

#Out of all samples collected, 54.73% of upper Bay and 
#89.82% of lower Bay samples did not contain M. arenaria. 

length(M.dens[M.dens==0&region=="UB"])/length(M.dens[region=="UB"])
length(M.dens[M.dens==0&region=="LB"])/length(M.dens[region=="LB"])

#Throughout all samples, densities of Tagelus plebeius were 13.07 times 
#higher than M. arenaria densities (p < 0.001, d = 0.02, Fig. 2b). 

mean(T.dens)/mean(M.dens)
#13.07733

new.frame.species.dens=data.frame("Density"=c(T.dens,M.dens),"Species"=c(rep("T",length(T.dens)),rep("M",length(M.dens))))
boots(response=new.frame.species.dens$Density,pred=new.frame.species.dens$Species,higher="T",lower="M")
#0.0001
ES(new.frame.species.dens$Density[new.frame.species.dens$Species=="T"],new.frame.species.dens$Density[new.frame.species.dens$Species=="M"])
#0.01570661

#Densities of Tagelus plebeius were 8.37 times higher at 
#sites in the lower Bay than at sites in the upper Bay 
#(p < 0.001, d = 0.04). 

mean(T.dens[region=="LB"])/mean(T.dens[region=="UB"])
#8.365932
boots(response=T.dens,pred=region,higher="LB",lower="UB")
#0.0001
ES(T.dens[region=="LB"],T.dens[region=="UB"])
#0.03654177

mean(T.dens[region=="UB"&river!="Western Shore"])/mean(T.dens[region=="UB"&river=="Western Shore"])
#6.580906
river.lump.EB=sub("Chester River","Eastern Bay",river,ignore.case=F) #Call Chester River "Eastern Bay" for analysis purposes
boots(response=T.dens[region=="UB"],pred=river.lump.EB[region=="UB"],lower="Western Shore",higher="Eastern Bay")
#0.0001
ES(T.dens[region=="UB"&river!="Western Shore"],T.dens[region=="UB"&river=="Western Shore"])
#0.0285342

#The maximum density observed for T. plebeius was 218.18 m-2 in 
#the lower Bay in Lynnhaven (Linkhorn Bay) in summer 2013. 

max(T.dens)
site[T.dens==max(T.dens)]
year[T.dens==max(T.dens)]
season[T.dens==max(T.dens)]

#Figure 2

jpeg("density spatial.jpg", width = 12, height = 10,units="in",res=300)

par(mfrow=c(1,2),mar=c(1,1,1,1))
plot(c(-77.38960,-77.38960,-75.60290,-75.60290),
     c(36.8145,39.71144,36.85145,39.71144),
     pch=19,col="white",axes=FALSE,xlab="",ylab="")
plot(cb_coastline,lwd=1,col="gray78",border="gray65",add=TRUE)
site.list=loc.sites
site.list=data.frame("sites"=as.character(names(site.list[,1])),
                     "lat"=unname(site.list[,1]),
                     "lon"=unname(site.list[,2]),
                     "M.dens"=rep(NA,nrow(site.list)),
                     "T.dens"=rep(NA,nrow(site.list)))
for(i in 1:nrow(site.list)){
  site.list[i,4]=round(mean(na.omit(M.dens[site==site.list[i,1]])),4)
  site.list[i,5]=round(mean(na.omit(T.dens[site==site.list[i,1]])),4)
  }
site.list=site.list[-8,]
site.list$lon=-1*site.list$lon
site.list=site.list[order(site.list$M.dens,decreasing=TRUE),]
coordinates(site.list) = ~lon + lat
plot(site.list,
     pch = 21,
     col="black",
     bg="gray33",
     # size the points according to the density value
     cex = site.list$M.dens/4+1,
     add = TRUE)
text(txt.a,x=-77.27023,y=39.64093,cex=2)

plot(c(-77.38960,-77.38960,-75.60290,-75.60290),
     c(36.8145,39.71144,36.85145,39.71144),
     pch=19,col="white",axes=FALSE,xlab="",ylab="")
plot(cb_coastline,lwd=1,col="gray78",border="gray65",add=TRUE)

site.list=site.list[order(site.list$T.dens,decreasing=TRUE),]
plot(site.list,
     pch = 21,
     col="black",
     bg="gray33",
     # size the points according to the density value
     cex = site.list$T.dens/4+1,
     add = TRUE)
text(txt.b,x=-77.27023,y=39.64093,cex=2)
legend(x="topright",legend=c(0,5,10,15,20,25,30),
       pt.cex=c(0,5,10,15,20,25,30)/4+1,
       pch = 21,
       col="black",
       pt.bg="gray33",
       y.intersp=2.2,
       x.intersp=2,
       bty = "n",
       title="Density",
       cex=1.5)

dev.off()

####################################################

### Shell length

mya.lower=na.omit(lengths.mya.tag[,1])
tag.lower=na.omit(lengths.mya.tag[,2])
mya.upper=na.omit(lengths.mya.tag[,3])
tag.upper=na.omit(lengths.mya.tag[,4])

#Figure 3

jpeg("length box.jpg", width = 4.5, height = 5,units="in",res=300)

par(mfrow=c(1,2),mar=c(4,4.1,3.5,1))

boxplot(mya.lower,mya.upper,names=c("Lower\nBay  ","Upper\nBay  "),
        ylab="Length (mm)",las=2,cex.lab=1.0,cex.axis=1.0,lwd=2,ylim=c(0,100))
points(x=1,y=mean(mya.lower),pch=2,bg="white")
points(x=2,y=mean(mya.upper),pch=2,bg="white")

text(x=0.33,y=100,labels="a.",pos=4,cex=1.2)

boxplot(tag.lower,tag.upper,names=c("Lower\nBay  ","Upper\nBay  "),
        ylab="Length (mm)",las=2,cex.lab=1.0,cex.axis=1.0,lwd=2,ylim=c(0,100))
points(x=1,y=mean(tag.lower),pch=2,bg="white")
points(x=2,y=mean(tag.upper),pch=2,bg="white")

text(x=0.33,y=100,labels="b.",pos=4,cex=1.2)


dev.off()

new.frame.lengths.mya.tag=data.frame("length"=c(mya.lower,tag.lower,mya.upper,tag.upper),"type"=c(rep("mya.lower",length(mya.lower)),rep("tag.lower",length(tag.lower)),rep("mya.upper",length(mya.upper)),rep("tag.upper",length(tag.upper))))

# Average shell length of M. arenaria was 1.43 times greater 
# at sites in the upper Bay than in the lower Bay (p < 0.001, 
# d = 0.07; Fig. 3a). 

mean(new.frame.lengths.mya.tag$length[new.frame.lengths.mya.tag$type=="mya.upper"])/mean(new.frame.lengths.mya.tag$length[new.frame.lengths.mya.tag$type=="mya.lower"])
#1.430836
boots(response=new.frame.lengths.mya.tag$length,pred=new.frame.lengths.mya.tag$type,lower="tag.lower",higher="tag.upper")
#0.0001
ES(new.frame.lengths.mya.tag$length[new.frame.lengths.mya.tag$type=="tag.upper"],new.frame.lengths.mya.tag$length[new.frame.lengths.mya.tag$type=="tag.lower"])
#0.0728947

# Similarly, T. plebeius at sites in the upper Bay were 2.07 
# times larger than those at sites in the lower Bay (p < 0.001, 
# d = 0.04; Fig. 3b). 

mean(new.frame.lengths.mya.tag$length[new.frame.lengths.mya.tag$type=="tag.upper"])/mean(new.frame.lengths.mya.tag$length[new.frame.lengths.mya.tag$type=="tag.lower"])
#2.068626
boots(response=new.frame.lengths.mya.tag$length,pred=new.frame.lengths.mya.tag$type,lower="mya.lower",higher="mya.upper")
#0.0001
ES(new.frame.lengths.mya.tag$length[new.frame.lengths.mya.tag$type=="mya.upper"],new.frame.lengths.mya.tag$length[new.frame.lengths.mya.tag$type=="mya.lower"])
#0.03567499

#Only 5.56% of M. arenaria collected in the lower Bay were greater 
#than 50 mm in shell length, while 29.73% of upper Bay M. arenaria 
#were 50 mm or larger.

length(new.frame.lengths.mya.tag$length[new.frame.lengths.mya.tag$type=="mya.lower"&new.frame.lengths.mya.tag$length>=50])/length(new.frame.lengths.mya.tag$length[new.frame.lengths.mya.tag$type=="mya.lower"])
#0.05555556

length(new.frame.lengths.mya.tag$length[new.frame.lengths.mya.tag$type=="mya.upper"&new.frame.lengths.mya.tag$length>=50])/length(new.frame.lengths.mya.tag$length[new.frame.lengths.mya.tag$type=="mya.upper"])
#0.2973287

####################################################

### Density trends

# Figure 4

cols2=c("LB"="gray28","UB"="white") 

# Adding two 'NA' rows to the mya data
# This adds a fall 2013 sampling period for the lower bay,
# and a spring 2013 sampling period for the upper bay.
# These are just placeholders for plotting.
mya[nrow(mya)+1,]=NA  
mya[nrow(mya)+1,]=NA  
mya$Year[nrow(mya)]="2013" 
mya$Season[nrow(mya)]="Fall" 
mya$Region[nrow(mya)]="LB" 
mya$Year[nrow(mya)-1]="2013"  
mya$Season[nrow(mya)-1]="Spring"
mya$Region[nrow(mya)-1]="UB"  

mya$year.seas=do.call(paste, c(mya[c("Year", "Season")], sep = " ")) 
mya$alpha.cat=NA
mya$alpha.cat[mya$year.seas=="2011 Fall"]="A"
mya$alpha.cat[mya$year.seas=="2012 Spring"]="B"
mya$alpha.cat[mya$year.seas=="2012 Summer"]="C"
mya$alpha.cat[mya$year.seas=="2012 Fall"]="D"
mya$alpha.cat[mya$year.seas=="2013 Spring"]="E"
mya$alpha.cat[mya$year.seas=="2013 Summer"]="F"
mya$alpha.cat[mya$year.seas=="2013 Fall"]="G"


summary.mya.dens=summarySE(mya,measurevar="M.Corr.Dens",groupvars=c("alpha.cat","Region"))
summary.mya.dens$text=c("","","","","","","","","","NA","","","NA","")
txt.dens.lab=expression(paste("Density (m"^"-2",") \u00B1 SE"))

jpeg("Season region.jpg", width = 7, height = 9,units="in",res=300)

ggplot.mya.dens = ggplot(summary.mya.dens, aes(x=alpha.cat, y=M.Corr.Dens, fill=Region)) + 
  geom_bar(position=position_dodge(), stat="identity",
           colour="black", #Use black outlines,
           size=.3) +      #Thinner lines
  geom_errorbar(aes(ymin=M.Corr.Dens-se, ymax=M.Corr.Dens+se),
                size=.3,    #Thinner lines
                width=.2,  # Width of the error bars
                position=position_dodge(.9)) +
  xlab("Season") +
  ylab(txt.dens.lab) +
  scale_fill_manual(name="Region",
                    values=cols2,
                    labels=c("Lower Bay","Upper Bay")) +
  ggtitle("") +
  geom_text(aes(x=-Inf,y=6.2,hjust=0,vjust=1,label="   a.")) +
  geom_text(data=summary.mya.dens,aes(y=0,label=text),position=position_dodge(.9),vjust=0,size=4.3) +
  scale_x_discrete(labels = c("A" = "2011\nFall","B" = "2012\nSpring",
                              "C"="2012\nSummer","D"="2012\nFall",
                              "E"="2013\nSpring","F"="2013\nSummer",
                              "G"="2013\nFall")) +
  theme_cowplot()
# Adding a solid border
ggplot.mya.dens = ggplot.mya.dens + theme(panel.border = element_rect(fill=NA,color="black", size=1, 
                                           linetype="solid"))

summary.tag.dens=summarySE(mya,measurevar="T.Dens",groupvars=c("alpha.cat","Region"))
summary.tag.dens$text=c("","","","","","","","","","NA","","","NA","")

ggplot.tag.dens = ggplot(summary.tag.dens, aes(x=alpha.cat, y=T.Dens, fill=Region)) + 
  geom_bar(position=position_dodge(), stat="identity",
           colour="black", #Use black outlines,
           size=.3) +      #Thinner lines
  geom_errorbar(aes(ymin=T.Dens-se, ymax=T.Dens+se),
                size=.3,    #Thinner lines
                width=.2,  # Width of the error bars
                position=position_dodge(.9)) +
  xlab("Season") +
  ylab(txt.dens.lab) +
  scale_fill_manual(name="Region",
                    values=cols2,
                    labels=c("Lower Bay","Upper Bay")) +
  ggtitle("") +
  geom_text(aes(x=-Inf,y=28,hjust=0,vjust=1,label="   b.")) +
  geom_text(data=summary.tag.dens,aes(y=0,label=text),position=position_dodge(.9),vjust=0,size=4.3) +
  scale_x_discrete(labels = c("A" = "2011\nFall","B" = "2012\nSpring",
                              "C"="2012\nSummer","D"="2012\nFall",
                              "E"="2013\nSpring","F"="2013\nSummer",
                              "G"="2013\nFall")) +
  theme_cowplot()

ggplot.tag.dens = ggplot.tag.dens + theme(panel.border = element_rect(fill=NA,color="black", size=1, 
                                           linetype="solid"))

multiplot(ggplot.mya.dens, ggplot.tag.dens, cols=1)

dev.off()


# Figure 5

mya$simp.sub="A"
mya$simp.sub[mya$Sb=="SG"]="B"
mya$simp.sub[mya$Sb=="SH"]="B"
mya$simp.sub[is.na(mya$M.Corr.Dens)]=NA


summary.mya.dens2=summarySE(mya,measurevar="M.Corr.Dens",groupvars=c("simp.sub"))
summary.mya.dens2=na.omit(summary.mya.dens2)

jpeg("dens substrate.jpg", width = 4, height = 7,units="in",res=300)

ggplot.mya.dens2=ggplot(summary.mya.dens2, aes(x=simp.sub, y=M.Corr.Dens)) + 
  geom_bar(position=position_dodge(), stat="identity",
           colour="gray28", 
           size=.3) +      #Thinner lines
  geom_errorbar(aes(ymin=M.Corr.Dens-se, ymax=M.Corr.Dens+se),
                size=.3,    #Thinner lines
                width=.2,  # Width of the error bars
                position=position_dodge(.9)) +
  xlab("Habitat") +
  ylab(txt.dens.lab) +
  ggtitle("") +
  geom_text(aes(x=-Inf,y=1.25,hjust=0,vjust=1,label="   a.")) +
  scale_x_discrete(labels = c("A" = "Simple","B" = "Complex")) +
  theme_cowplot() 

ggplot.mya.dens2 = ggplot.mya.dens2 + theme(panel.border = element_rect(fill=NA,color="black", size=1, 
                                           linetype="solid"))

mya$sub.cat=NA
mya$sub.cat[mya$Sb=="MU"]="A"
mya$sub.cat[mya$Sb=="GR"]="B"
mya$sub.cat[mya$Sb=="SA"]="C"
mya$sub.cat[mya$Sb=="SH"]="D"
mya$sub.cat[mya$Sb=="SG"]="E"
mya$sub.cat[is.na(mya$T.Corr.Dens)]=NA

summary.tag.dens2=summarySE(mya,measurevar="T.Dens",groupvars=c("sub.cat"))
summary.tag.dens2=na.omit(summary.tag.dens2)

ggplot.tag.dens2=ggplot(summary.tag.dens2, aes(x=sub.cat, y=T.Dens)) + 
  geom_bar(position=position_dodge(), stat="identity",
           colour="gray28", 
           size=.3) +      #Thinner lines
  geom_errorbar(aes(ymin=T.Dens-se, ymax=T.Dens+se),
                size=.3,    #Thinner lines
                width=.2,  # Width of the error bars
                position=position_dodge(.9)) +
  xlab("Habitat") +
  ylab(txt.dens.lab) +
  ggtitle("") +
  geom_text(aes(x=-Inf,y=25,hjust=0,vjust=1,label="   b.")) +
  scale_x_discrete(labels = c("A" = "Mud","B" = "Sand","C"="Gravel","D"="Shell","E"="Seagrass"))+
  theme_cowplot() 

ggplot.tag.dens2 =  ggplot.tag.dens2 + theme(panel.border = element_rect(fill=NA,color="black", size=1, 
                                            linetype="solid"))

multiplot(ggplot.mya.dens2, ggplot.tag.dens2, cols=1)

dev.off()

mean(M.dens[region=="LB"])/mean(M.dens[region=="UB"])
#2.750353
boots(response=M.dens,pred=region,higher="LB",lower="UB")
#0.0205
ES(M.dens[region=="LB"],M.dens[region=="UB"])
#0.008370264


####################################################

#GAM model output

####################################################

#Mya PA and density

#Substitute seagrass category with "A" to make seagrass the intercept
sb=sub("SG","A",sb,ignore.case=F)

new.frame.mya.PA=na.omit(data.frame("M.dens"=M.dens,"mya.PA"=mya.PA,
                              "region"=region,
                              "year"=year,"season"=season,"sb"=sb,
                              "temp"=temp,"sal"=sal,"do"=do,
                              "rays"=rays,"crabs"=crabs,"fish"=fish,
                              "day"=day,"lat"=lat,"lon"=lon))
new.frame.mya.PA.subset=new.frame.mya.PA[new.frame.mya.PA$season!="Fall"&new.frame.mya.PA$year=="2012",]
new.frame.mya.PA.subset$sb2="S"
new.frame.mya.PA.subset$sb2[new.frame.mya.PA.subset$sb=="A"]="C"
new.frame.mya.PA.subset$sb2[new.frame.mya.PA.subset$sb=="SH"]="C"

new.frame.mya.PA.subset=new.frame.mya.PA.subset[order(new.frame.mya.PA.subset$sb2),]

gam.mya.PA = gam(mya.PA ~ temp + sal + do +
             rays + crabs + fish + sb2 +
             s(day,k = 2) + s(lat, lon),
             family = binomial(link=logit), data = new.frame.mya.PA.subset)
summary(gam.mya.PA)
par(mfrow=c(1,1))
plot(resid(gam.mya.PA))
#plot(gam.mya.dens)
gam.check(gam.mya.PA)

# Estimate Std. Error z value Pr(>|z|)  
# (Intercept) 147.0133    62.4126   2.356   0.0185 *
# temp         -4.7924     2.3402  -2.048   0.0406 *
# sal          -1.2670     0.7534  -1.682   0.0926 .
# do           -0.5548     0.7848  -0.707   0.4797  
# rays         -7.9367    15.5083  -0.512   0.6088  
# crabs         0.3443     0.7681   0.448   0.6540  
# fish         -0.3736     0.6507  -0.574   0.5659  
# sb2S         -5.9714     2.8196  -2.118   0.0342 *

#The odds of finding M. arenaria in seagrass or shell were 
#392.04 times greater than in less-complex habitats such 
#as mud, sand, and gravel. 

exp(summary(gam.mya.PA)$p.coeff[1])/exp(summary(gam.mya.PA)$p.coeff[1]+summary(gam.mya.PA)$p.coeff[8])
#392.0432

new.frame.mya.dens=new.frame.mya.PA[new.frame.mya.PA$M.dens>0,]
new.frame.mya.dens$sb2="S"
new.frame.mya.dens$sb2[new.frame.mya.dens$sb=="A"]="C"
new.frame.mya.dens$sb2[new.frame.mya.dens$sb=="SH"]="C"

new.frame.mya.dens=new.frame.mya.dens[order(new.frame.mya.dens$sb2),]

gam.mya.dens=gam(log(M.dens) ~ temp + sal + do +
           rays + crabs + fish +
           sb2 + s(day,k = -1) + s(lat,lon),
           data=new.frame.mya.dens)
summary(gam.mya.dens)
plot(resid(gam.mya.dens))
#plot(gam.mya.PA)
gam.check(gam.mya.dens)

# Estimate Std. Error t value Pr(>|t|)  
# (Intercept)  6.11336    7.09343   0.862   0.3934  
# temp        -0.26662    0.28924  -0.922   0.3616  
# sal          0.17426    0.16874   1.033   0.3073  
# do          -0.31643    0.15659  -2.021   0.0493 *
# rays         0.09250    1.76181   0.053   0.9584  
# crabs       -0.03817    0.36956  -0.103   0.9182  
# fish         0.09665    0.17227   0.561   0.5776  
# sb2S        -0.76570    0.38284  -2.000   0.0516 .

#When M. arenaria were present, densities in seagrass 
#or shell were 2.15 times greater than in less-complex 
#habitats such as mud, sand, and gravel.  

# Back transform

exp(summary(gam.mya.dens)$p.coeff[1])/exp(summary(gam.mya.dens)$p.coeff[1]+summary(gam.mya.dens)$p.coeff[8])
#2.150491 

####################################################
#Tagelus PA and density

new.frame.tag.PA=na.omit(data.frame("T.dens"=T.dens,"tag.PA"=tag.PA,
                             "region"=region,
                             "year"=year,"season"=season,"sb"=sb,
                             "temp"=temp,"sal"=sal,"do"=do,"fish"=fish,
                             "rays"=rays,"crabs"=crabs,
                             "day"=day,"lat"=lat,"lon"=lon))
new.frame.tag.PA=new.frame.tag.PA[order(sb),]
gam.tag.PA = gam(tag.PA ~ temp + sal + do +
           rays + crabs + fish +
           sb + s(day,k=-1) + s(lat, lon),
           family = binomial(link=logit),data = new.frame.tag.PA)
summary(gam.tag.PA)
plot(resid(gam.tag.PA))
#plot(gam.tag.PA)
#gam.check(gam.tag.PA)

# Estimate Std. Error z value Pr(>|z|)    
# (Intercept) 12.13791    5.45212   2.226 0.025996 *  
# temp        -0.28170    0.16429  -1.715 0.086400 .  
# sal         -0.29007    0.16331  -1.776 0.075698 .  
# do           0.21524    0.17343   1.241 0.214592    
# rays         1.45280    2.89340   0.502 0.615593    
# crabs       -0.08982    0.18104  -0.496 0.619796    
# fish        -0.12296    0.14545  -0.845 0.397909    
# sbGR        -0.45501    1.32439  -0.344 0.731177    
# sbMU        -2.45505    1.47527  -1.664 0.096086 .  
# sbSA        -1.36868    0.80962  -1.691 0.090927 .  
# sbSH        -2.42278    0.69434  -3.489 0.000484 ***

# The odds of finding T. plebeius in seagrass were 11.65 times 
# greater than in mud (z = 1.47, p = 0.10), 3.95 times greater 
# than in sand (z = 1.81, p = 0.09), and 11.28 times greater 
# than in shell (z = 0.69, p = 0.0005). 

exp(summary(gam.tag.PA)$p.coeff[1])/exp(summary(gam.tag.PA)$p.coeff[1]+summary(gam.tag.PA)$p.coeff[9])
#11.64703 
exp(summary(gam.tag.PA)$p.coeff[1])/exp(summary(gam.tag.PA)$p.coeff[1]+summary(gam.tag.PA)$p.coeff[10])
#3.93017
exp(summary(gam.tag.PA)$p.coeff[1])/exp(summary(gam.tag.PA)$p.coeff[1]+summary(gam.tag.PA)$p.coeff[11])
#11.27721

new.frame.tag.dens=new.frame.tag.PA[new.frame.tag.PA$T.dens>0,]
gam.tag.dens=gam(log(T.dens) ~ temp + sal + do +
               rays + crabs + fish +
               sb + s(day,k=-1) + s(lat,lon),
               data=new.frame.tag.dens)
summary(gam.tag.dens)
plot(resid(gam.tag.dens))
#gam.check(gam.tag.dens)

# Estimate Std. Error t value Pr(>|t|)  
# (Intercept) -4.562540   4.224297  -1.080   0.2819  
# temp         0.014895   0.111522   0.134   0.8939  
# sal          0.305308   0.143264   2.131   0.0348 *
# do          -0.042060   0.095287  -0.441   0.6596  
# rays         0.633722   1.249705   0.507   0.6129  
# crabs       -0.005122   0.152447  -0.034   0.9732  
# fish        -0.146828   0.120758  -1.216   0.2260  
# sbGR         0.150685   0.965269   0.156   0.8762  
# sbMU         1.268475   0.955589   1.327   0.1865  
# sbSA         1.684157   0.647120   2.603   0.0102 *
# sbSH         0.127457   0.588402   0.217   0.8288  

#When T. plebeius were present, densities in sand 
#were 4.63 times greater than in gravel, 5.39 times 
#greater than in seagrass, and 4.74 times greater 
#than in shell. 

# Back transform

exp(summary(gam.tag.dens)$p.coeff[1]+summary(gam.tag.dens)$p.coeff[10])/exp(summary(gam.tag.dens)$p.coeff[1]+summary(gam.tag.dens)$p.coeff[8])
#4.634239 

exp(summary(gam.tag.dens)$p.coeff[1]+summary(gam.tag.dens)$p.coeff[10])/exp(summary(gam.tag.dens)$p.coeff[1])
#5.387907 

exp(summary(gam.tag.dens)$p.coeff[1]+summary(gam.tag.dens)$p.coeff[10])/exp(summary(gam.tag.dens)$p.coeff[1]+summary(gam.tag.dens)$p.coeff[11])
#4.743143 


####################################################

#Recruitment

# Recruitment was characterized by an Autoregressive 
# Moving Average (ARIMA[2, 1, 1]), with a negative 
# trend (drift) of -0.03 million clams ha-1 y-1. 

recruit=recruit_time_series$Mya_mean_millions_ha
recruit_time_series$sd_recruit=NA
for(i in 1:length(recruit))
{
  recruit_time_series$sd_recruit[i]=sd(c(recruit_time_series$Mya_site_1_millions_ha[i],
                                       recruit_time_series$Mya_site_2_milions_ha[i]))
}
recruit.fit=auto.arima(recruit,include.mean=TRUE)
recruit.fit
# Series: recruit 
# ARIMA(2,1,1) with drift         

#          ar1      ar2      ma1    drift
#       -0.0031  -0.7524  -0.4985  -0.0307
# s.e.   0.1729   0.1269   0.1908   0.0149
# 
# sigma^2 estimated as 0.09588:  log likelihood=-7.91
# AIC=25.82   AICc=27.82   BIC=33.73

#Figure 6

jpeg("recruit.jpg", width = 6, height = 4,units="in",res=300)
par(mar=c(4,5,3.5,1))

txt.clam.lab=expression(paste("Clams ha"^"-1"," (millions)"))
recruit_plot=barplot(recruit_time_series$Mya_mean_millions_ha,names.arg=recruit_time_series$Year,ylab=txt.clam.lab,ylim=c(0,2.5))
arrows(recruit_plot,recruit_time_series$Mya_mean_millions_ha+(recruit_time_series$sd_recruit/sqrt(2)),
       recruit_plot,recruit_time_series$Mya_mean_millions_ha-(recruit_time_series$sd_recruit/sqrt(2)),
       code=3,angle=90,length=0.02,lwd=1)
lines(x = 1:37,y=recruit.fit$fitted,col='black',lwd=2)
text(x=11.60,y=0.08,labels="0")
text(x=22.27,y=0.08,labels="0")
text(x=24.77,y=0.08,labels="0")
text(x=28.32,y=0.08,labels="0")
text(x=29.61,y=0.08,labels="0")
text(x=31.90,y=0.08,labels="0")
text(x=33.17,y=0.08,labels="0")
text(x=34.32,y=0.08,labels="0")
text(x=35.59,y=0.08,labels="0")
text(x=36.80,y=0.08,labels="0")
text(x=38.01,y=0.08,labels="0")
text(x=39.15,y=0.08,labels="0")
text(x=40.30,y=0.08,labels="0")
text(x=41.49,y=0.08,labels="0")
text(x=42.70,y=0.08,labels="0")
text(x=43.91,y=0.08,labels="0")

box()
dev.off()
####################################################

### Disease GAMS

# Intensity

# Mean infection intensity for Mya arenaria was light 
# at upper Bay sites, with a mean of 0.48 on a 5 point 
# scale (Fig. 7a). 

mean(na.omit(M.mean.dis))
#0.4839894

# Infection intensity in M. arenaria increased by a 
# factor of 0.55 for each degree increase in temperature, 
# and increased by a factor of 0.07 for each mm in shell 
# length (back-transformed from Table 2). 

new.frame.mya.int=na.omit(data.frame("M.mean.dis"=M.mean.dis,
                              "year"=year,"season"=season,
                              "M.dens"=M.dens,"M.length"=M.length,
                              "temp"=temp,"sal"=sal,"do"=do,
                              "day"=day,"lat"=lat,"lon"=lon))
gam.mya.int=gam(log(M.mean.dis+0.1) ~ temp + sal + do + 
                M.length + M.dens + s(day,k = -1) + s(lat,lon),
                family=gaussian(link=identity),data=new.frame.mya.int)
summary(gam.mya.int)
#plot(gam.mya.int)
plot(resid(gam.mya.int))
#gam.check(gam.mya.int)
# 
# Estimate Std. Error t value Pr(>|t|)    
# (Intercept) -2.190e+01  2.094e+00 -10.454 4.93e-15 ***
# temp         4.380e-01  1.210e-01   3.620 0.000614 ***
# sal          2.657e-01  1.292e-01   2.057 0.044179 *  
# do           5.350e-01  6.461e-02   8.280 1.88e-11 ***
# M.length     6.440e-02  7.528e-03   8.555 6.50e-12 ***
# M.dens       8.134e-05  2.258e-03   0.036 0.971388  

exp(summary(gam.mya.int)$p.coeff[2])-1
#0.5495735

exp(summary(gam.mya.int)$p.coeff[3])-1
#0.3043692

exp(summary(gam.mya.int)$p.coeff[4])-1
#0.7075057  

exp(summary(gam.mya.int)$p.coeff[5])-1
#0.06652305

mean(na.omit(M.mean.dis[river!="Western Shore"]))/mean(na.omit(M.mean.dis[river=="Western Shore"]))
#1.537558
new.data=data.frame("dis"=c(na.omit(M.mean.dis[river!="Western Shore"]),na.omit(M.mean.dis[river=="Western Shore"])),"sp"=c(rep("ES",length(na.omit(M.mean.dis[river!="Western Shore"]))),rep("WS",length(na.omit(M.mean.dis[river=="Western Shore"])))))
boots(response=new.data$dis,pred=new.data$sp,lower="WS",higher="ES")
#0.033
ES(new.data$dis[new.data$sp=="ES"],new.data$dis[new.data$sp=="WS"])
#0.02204815

# The mean infection intensity for T. plebeius was light 
# to moderate and was 1.57 times greater than that for 
# M. arenaria (p < 0.001, d = 0.03; Fig. 7b). 

mean(na.omit(T.mean.dis))
#0.7621138

mean(na.omit(T.mean.dis))/mean(na.omit(M.mean.dis))
#1.57465
new.data=data.frame("dis"=c(na.omit(T.mean.dis),na.omit(M.mean.dis)),"sp"=c(rep("T",length(na.omit(T.mean.dis))),rep("M",length(na.omit(M.mean.dis)))))
boots(response=new.data$dis,pred=new.data$sp,lower="M",higher="T")
#0.0001
ES(new.data$dis[new.data$sp=="T"],new.data$dis[new.data$sp=="M"])
#0.03110264

new.frame.tag.int=na.omit(data.frame("T.mean.dis"=T.mean.dis,
                              "year"=year,"season"=season,
                              "T.dens"=T.dens,"T.length"=T.length,
                              "temp"=temp,"sal"=sal,"do"=do,
                              "day"=day,"lat"=lat,"lon"=lon))
gam.tag.int=gam(log(T.mean.dis+0.1) ~ temp + sal + do + 
                  T.length + T.dens + s(day,k = -1) + s(lat,lon), 
                data=new.frame.tag.int)
summary(gam.tag.int)
#plot(gam.tag.int)
plot(resid(gam.tag.int))
#gam.check(gam.tag.int)

# Estimate Std. Error t value Pr(>|t|)    
# (Intercept) -4.232949   1.728481  -2.449  0.01581 *  
# temp         0.192477   0.067561   2.849  0.00519 ** 
# sal         -0.177422   0.057984  -3.060  0.00275 ** 
# do          -0.034243   0.031943  -1.072  0.28593    
# T.length     0.035427   0.006185   5.727 8.06e-08 ***
# T.dens       0.001779   0.003523   0.505  0.61448  


# Mean infection intensity for T. plebeius decreased by 
# a factor of 0.16 with each unit increase in salinity, 
# and increased by a factor of 0.21 with each unit 
# increase in temperature (back-transformed from Table 2). 

1-exp(summary(gam.tag.int)$p.coeff[3])
#0.1625736

exp(summary(gam.tag.int)$p.coeff[2])-1
#0.2122488

exp(summary(gam.tag.int)$p.coeff[5])-1
#0.03606164

#Prevalence

# Perkinsus sp. infection prevalence was low for M. arenaria, 
# averaging 29.21% over the course of the survey (2011-2013). 

mean(na.omit(M.Prop.Dis))
#0.2920833

mean(na.omit(T.Prop.Dis[river!="Western Shore"]))/mean(na.omit(T.Prop.Dis[river=="Western Shore"]))
#1.193218
new.data=data.frame("dis"=c(na.omit(T.Prop.Dis[river!="Western Shore"]),na.omit(T.Prop.Dis[river=="Western Shore"])),"sp"=c(rep("ES",length(na.omit(T.Prop.Dis[river!="Western Shore"]))),rep("WS",length(na.omit(T.Prop.Dis[river=="Western Shore"])))))
boots(response=new.data$dis,pred=new.data$sp,lower="WS",higher="ES")
#0.0017
ES(new.data$dis[new.data$sp=="ES"],new.data$dis[new.data$sp=="WS"])
#0.03063099

# Perkinsus sp. infection prevalence during the survey (2011-2013) 
# was 2.17 times higher in T. plebeius (Fig. 7c) than in M. arenaria
# (Fig. 7d; p < 0.001, d = 0.06). 

mean(na.omit(T.Prop.Dis))/mean(na.omit(M.Prop.Dis))
#2.172888
new.data=data.frame("dis"=c(na.omit(T.Prop.Dis),na.omit(M.Prop.Dis)),"sp"=c(rep("T",length(na.omit(T.Prop.Dis))),rep("M",length(na.omit(M.Prop.Dis)))))
boots(response=new.data$dis,pred=new.data$sp,lower="M",higher="T")
#0.0001
ES(new.data$dis[new.data$sp=="T"],new.data$dis[new.data$sp=="M"])
#0.06171843

new.frame.mya.prop=na.omit(data.frame("M.Prop.Dis"=M.Prop.Dis,
                              "year"=year,"season"=season,
                              "T.dens"=T.dens,"T.length"=T.length,
                              "temp"=temp,"sal"=sal,"do"=do,
                              "day"=day,"lat"=lat,"lon"=lon))
gam.mya.prop=gam(M.Prop.Dis ~ temp + sal + do + 
                T.length + T.dens + s(day,k = -1) + s(lat,lon), 
                data=new.frame.mya.prop)
summary(gam.mya.prop)
#plot(gam.mya.prop)
plot(resid(gam.mya.prop))
#gam.check(gam.mya.prop)

# Estimate Std. Error t value Pr(>|t|)    
# (Intercept) -2.301e+01  2.096e+00 -10.981 5.62e-15 ***
# temp         5.963e-01  6.825e-02   8.736 1.15e-11 ***
# sal          4.815e-01  4.319e-02  11.148 3.26e-15 ***
# do           1.924e-01  2.529e-02   7.608 6.41e-10 ***
# T.length     2.894e-02  4.008e-03   7.221 2.59e-09 ***
# T.dens       4.111e-04  1.616e-03   0.254      0.8   

new.frame.tag.prop=na.omit(data.frame("T.Prop.Dis"=T.Prop.Dis,
                              "year"=year,"season"=season,
                              "T.dens"=T.dens,"T.length"=T.length,
                              "temp"=temp,"sal"=sal,"do"=do,
                              "day"=day,"lat"=lat,"lon"=lon))
gam.tag.prop=gam(T.Prop.Dis ~ temp + sal + do + 
                T.length + T.dens + s(day,k = -1) + s(lat,lon), 
                data=new.frame.tag.prop)
summary(gam.tag.prop)
#plot(gam.tag.prop)
plot(resid(gam.tag.prop))
#gam.check(gam.tag.prop)

# Estimate Std. Error t value Pr(>|t|)   
# (Intercept) -3.179337   1.697536  -1.873   0.0644 . 
# temp         0.139696   0.067417   2.072   0.0412 * 
# sal          0.062034   0.054775   1.133   0.2605   
# do           0.096888   0.029572   3.276   0.0015 **
# T.length    -0.015595   0.008517  -1.831   0.0704 . 
# T.dens       0.001036   0.002915   0.356   0.7231   

####################################################

#Figure 7

jpeg("disease spatial.jpg", width = 6, height = 6.5,units="in",res=300)

par(mfrow=c(2,2),mar=c(1,1,1,1))
plot(c(-76.62237,-76.62237,-75.82592,-75.82592),
     c(38.76651,39.61286,38.76651,39.61286),
     pch=19,col="white",axes=FALSE,xlab="",ylab="")
plot(cb_coastline,lwd=1,col="gray78",border="gray65",add=TRUE)
site.list.ub=loc.sites[14:nrow(loc.sites),]
site.list.ub=data.frame("sites"=as.character(names(site.list.ub[,1])),
                     "lat"=unname(site.list.ub[,1]),
                     "lon"=unname(site.list.ub[,2]),
                     "M.dis.int"=rep(NA,nrow(site.list.ub)),
                     "T.dis.int"=rep(NA,nrow(site.list.ub)),
                     "M.dis.prev"=rep(NA,nrow(site.list.ub)),
                     "T.dis.prev"=rep(NA,nrow(site.list.ub)))
mya.ub=mya[mya$Region=="UB",]
site.ub=factor(as.character(na.omit(mya.ub$Site)))
M.mean.dis.ub=na.omit(mya.ub$M.Mean.Dis)
T.mean.dis.ub=na.omit(mya.ub$T.Mean.Dis)
M.prop.dis.ub=na.omit(mya.ub$M.Prop.Dis)
T.prop.dis.ub=na.omit(mya.ub$T.Prop.Dis)

for(i in 1:nrow(site.list.ub)){
  site.list.ub[i,4]=round(mean(na.omit(M.mean.dis.ub[site.ub==site.list.ub[i,1]])),4)
  site.list.ub[i,5]=round(mean(na.omit(T.mean.dis.ub[site.ub==site.list.ub[i,1]])),4)
  site.list.ub[i,6]=round(mean(na.omit(M.prop.dis.ub[site.ub==site.list.ub[i,1]])),4)
  site.list.ub[i,7]=round(mean(na.omit(T.prop.dis.ub[site.ub==site.list.ub[i,1]])),4)
}
site.list.ub$lon=-1*site.list.ub$lon
site.list.ub=site.list.ub[order(site.list.ub$M.dis.int,decreasing=TRUE),]
coordinates(site.list.ub) = ~lon + lat
plot(site.list.ub,
     pch = 21,
     col="black",
     bg="gray33",
     # size the points according to the density value
     cex = site.list.ub$M.dis.int*2 +0.5,
     add = TRUE)
text(txt.a,x=-76.58837,y=39.59201,cex=1.5)
text("Western Shore",x=-76.41992,y=39.11251,cex=1)
text("Chester River",x=-76.15820,y=39.16630,cex=1)
text("Eastern Bay",x=-76.10432,y=38.86718,cex=1)

plot(c(-76.62237,-76.62237,-75.82592,-75.82592),
     c(38.76651,39.61286,38.76651,39.61286),
     pch=19,col="white",axes=FALSE,xlab="",ylab="")
plot(cb_coastline,lwd=1,col="gray78",border="gray65",add=TRUE)

site.list.ub=site.list.ub[order(site.list.ub$T.dis.int,decreasing=TRUE),]
coordinates(site.list.ub) = ~lon + lat
plot(site.list.ub,
     pch = 21,
     col="black",
     bg="gray33",
     # size the points according to the density value
     cex = site.list.ub$T.dis.int*2 +0.5,
     add = TRUE)
text(txt.b,x=-76.58837,y=39.59201,cex=1.5)

legend(x="topright",legend=c("0.00","0.25","0.50","0.75","1.00","1.25","1.50"),
       pt.cex=c(0,0.25,0.5,0.75,1.0,1.25,1.5)*2+0.5,
       pch = 21,
       col="black",
       pt.bg="gray33",
       y.intersp=1.5,
       x.intersp=1,
       bty = "n",
       title="Intensity",
       cex=1.2)

txt.c=expression(paste("c."))
txt.d=expression(paste("d."))

plot(c(-76.62237,-76.62237,-75.82592,-75.82592),
     c(38.76651,39.61286,38.76651,39.61286),
     pch=19,col="white",axes=FALSE,xlab="",ylab="")
plot(cb_coastline,lwd=1,col="gray78",border="gray65",add=TRUE)

site.list.ub=site.list.ub[order(site.list.ub$M.dis.prev,decreasing=TRUE),]
coordinates(site.list.ub) = ~lon + lat
plot(site.list.ub,
     pch = 21,
     col="black",
     bg="gray33",
     # size the points according to the density value
     cex = site.list.ub$M.dis.prev*2.5 +0.5,
     add = TRUE)
text(txt.c,x=-76.58837,y=39.59201,cex=1.5)

plot(c(-76.62237,-76.62237,-75.82592,-75.82592),
     c(38.76651,39.61286,38.76651,39.61286),
     pch=19,col="white",axes=FALSE,xlab="",ylab="")
plot(cb_coastline,lwd=1,col="gray78",border="gray65",add=TRUE)

site.list.ub=site.list.ub[order(site.list.ub$T.dis.prev,decreasing=TRUE),]
coordinates(site.list.ub) = ~lon + lat
plot(site.list.ub,
     pch = 21,
     col="black",
     bg="gray33",
     # size the points according to the density value
     cex = site.list.ub$T.dis.prev*2.5 +0.5,
     add = TRUE)
text(txt.d,x=-76.58837,y=39.59201,cex=1.5)

legend(x="topright",legend=c("0.0","0.2","0.4","0.6","0.8","1.0"),
       pt.cex=c(0,0.2,0.4,0.6,0.8,1.0)*2.5+0.5,
       pch = 21,
       col="black",
       pt.bg="gray33",
       y.intersp=1.5,
       x.intersp=1,
       bty = "n",
       title="Prevalence",
       cex=1.2)

dev.off()

####################################################

# Table 2

tab2=data.frame("M-logit(P/A)"=rep(NA,13),
                "M-log(Density)"=rep(NA,13),
                "M-log(Intensity)"=rep(NA,13),
                "M-Dis.Prevalence"=rep(NA,13),
                "T-logit(P/A)"=rep(NA,13),
                "T-log(Density)"=rep(NA,13),
                "T-log(Intensity)"=rep(NA,13),
                "T-Dis.Prevalence"=rep(NA,13))

tab2[,1]=paste(c(round(unname(summary(gam.mya.dens)$p.coeff),2),NA,NA,NA,NA,NA)," (",c(round(unname(summary(gam.mya.dens)$se[1:8]),2),NA,NA,NA,NA,NA),")")
tab2[,2]=paste(c(round(unname(summary(gam.mya.PA)$p.coeff),2),NA,NA,NA,NA,NA)," (",c(round(unname(summary(gam.mya.PA)$se[1:8]),2),NA,NA,NA,NA,NA),")")
tab2[,3]=paste(c(round(unname(summary(gam.mya.int)$p.coeff),2)[1:4],NA,NA,NA,NA,NA,NA,NA,round(unname(summary(gam.mya.int)$p.coeff),2)[5:6])," (",c(round(unname(summary(gam.mya.int)$se),2)[1:4],NA,NA,NA,NA,NA,NA,NA,round(unname(summary(gam.mya.int)$se),2)[5:6]),")")
tab2[,4]=paste(c(round(unname(summary(gam.mya.prop)$p.coeff),2)[1:4],NA,NA,NA,NA,NA,NA,NA,round(unname(summary(gam.mya.prop)$p.coeff),2)[5:6])," (",c(round(unname(summary(gam.mya.prop)$se),2)[1:4],NA,NA,NA,NA,NA,NA,NA,round(unname(summary(gam.mya.prop)$se),2)[5:6]),")")
tab2[,5]=paste(c(round(unname(summary(gam.tag.dens)$p.coeff),2),NA,NA)," (",c(round(unname(summary(gam.tag.dens)$se[1:11]),2),NA,NA),")")
tab2[,6]=paste(c(round(unname(summary(gam.tag.PA)$p.coeff),2),NA,NA)," (",c(round(unname(summary(gam.tag.PA)$se[1:11]),2),NA,NA),")")
tab2[,7]=paste(c(round(unname(summary(gam.tag.int)$p.coeff),2)[1:4],NA,NA,NA,NA,NA,NA,NA,round(unname(summary(gam.tag.int)$p.coeff),2)[5:6])," (",c(round(unname(summary(gam.tag.int)$se),2)[1:4],NA,NA,NA,NA,NA,NA,NA,round(unname(summary(gam.tag.int)$se),2)[5:6]),")")
tab2[,8]=paste(c(round(unname(summary(gam.tag.prop)$p.coeff),2)[1:4],NA,NA,NA,NA,NA,NA,NA,round(unname(summary(gam.tag.prop)$p.coeff),2)[5:6])," (",c(round(unname(summary(gam.tag.prop)$se),2)[1:4],NA,NA,NA,NA,NA,NA,NA,round(unname(summary(gam.tag.prop)$se),2)[5:6]),")")
tab2

####################################################

#Time series

M.prev.dis=c(84,70,100,69,28,94,85,81,93,NA,NA,24,82,80)/100
M.prev.dis.SD=c(24,4,2,25,36,5,18,9,0,NA,NA,25,13,26)/100
M.dis.n=c(4,2,4,3,4,3,4,3,1,NA,NA,7,3,3)
T.prev.dis=c(NA,60,99,81,94,100,97,87,85,NA,NA,28,86,94)/100
T.prev.dis.SD=c(NA,0,2,16,10,0,3,12,2,NA,NA,22,21,10)/100
M.int.dis=c(1.93,2.15,2.43,1.37,0.53,1.90,2.40,1.30,1.40,NA,NA,1.17,2.10,1.78)
M.int.dis.SD=c(0.53,0.21,0.96,0.64,0.61,1.34,1.36,0.26,0.00,NA,NA,0.41,0.43,0.33)
T.int.dis=c(NA,1.70,1.40,1.00,1.73,2.55,1.70,1.23,1.60,NA,NA,1.00,1.31,1.57)
T.int.dis.SD=c(NA,0.00,0.26,0.00,0.61,0.01,0.17,0.32,0.57,NA,NA,0.00,0.29,0.37)
T.dis.n=c(NA,1,3,3,3,3,3,3,2,NA,NA,6,7,9)

# Prevalence of infection was moderate to high between 2000 and 
# 2013, with mean infection rates of 68.46% for M. arenaria 
# and 81.86% for T. plebeius (Figure 8a).

pooled.mean.M.prev=sum(na.omit(M.prev.dis)*na.omit(M.dis.n))/sum(na.omit(M.dis.n))
#0.6846341
pooled.sd.M.prev=sum((na.omit(M.dis.n)-1)*na.omit(M.prev.dis.SD))/(sum(na.omit(M.dis.n))-3)
#0.1447368
pooled.mean.T.prev=sum(na.omit(T.prev.dis)*na.omit(T.dis.n))/sum(na.omit(T.dis.n))
#0.8186047
pooled.sd.T.prev=sum((na.omit(T.dis.n)-1)*na.omit(T.prev.dis.SD))/(sum(na.omit(T.dis.n))-3)
#0.101

pooled.mean.M.int=sum(na.omit(M.int.dis)*na.omit(M.dis.n))/sum(na.omit(M.dis.n))
#1.668293
pooled.sd.M.int=sum((na.omit(M.dis.n)-1)*na.omit(M.int.dis.SD))/(sum(na.omit(M.dis.n))-3)
#0.5013158
pooled.mean.T.int=sum(na.omit(T.int.dis)*na.omit(T.dis.n))/sum(na.omit(T.dis.n))
#1.465814
pooled.sd.T.int=sum((na.omit(T.dis.n)-1)*na.omit(T.int.dis.SD))/(sum(na.omit(T.dis.n))-3)
#0.20025

# Across all years in the time series, average prevalence of 
# infection was similar between species (d = 0.25, p = 0.16), 
# and average infection intensities were light and similar 
# between M. arenaria and T. plebeius (d = 0.04, p = 0.18). 

boots_pooled(lower=M.prev.dis,higher=T.prev.dis,lower.n=M.dis.n,higher.n=T.dis.n)
#0.157

ES_pooled(a=T.prev.dis,b=M.prev.dis,a.n=T.dis.n,b.n=M.dis.n,a.sd=T.prev.dis.SD,b.sd=M.prev.dis.SD)
#0.2502823

boots_pooled(lower=T.int.dis,higher=M.int.dis,lower.n=T.dis.n,higher.n=M.dis.n)
#0.1794

ES_pooled(a=M.int.dis,b=T.int.dis,a.n=M.dis.n,b.n=T.dis.n,a.sd=M.int.dis.SD,b.sd=T.int.dis.SD)
#0.04126828

#River flow

# Annually averaged Susquehanna River discharge can be obtained 
# from the USGS water quality monitoring station at Harrisburg, 
# PA. National Water Information System at 
# https://waterdata.usgs.gov/usa/nwis

flows=c(mean(susq_flow$flow[susq_flow$year==2000]),
        mean(susq_flow$flow[susq_flow$year==2001]),
        mean(susq_flow$flow[susq_flow$year==2002]),
        mean(susq_flow$flow[susq_flow$year==2003]),
        mean(susq_flow$flow[susq_flow$year==2004]),
        mean(susq_flow$flow[susq_flow$year==2005]),
        mean(susq_flow$flow[susq_flow$year==2006]),
        mean(susq_flow$flow[susq_flow$year==2007]),
        mean(susq_flow$flow[susq_flow$year==2008]),
        mean(susq_flow$flow[susq_flow$year==2009]),
        mean(susq_flow$flow[susq_flow$year==2010]),
        mean(susq_flow$flow[susq_flow$year==2011]),
        mean(susq_flow$flow[susq_flow$year==2012]),
        mean(susq_flow$flow[susq_flow$year==2013]))

# Temperatures can be obtained from the Chesapeake Bay 
# Program Water Quality Database 
# http://www.chesapeakebay.net/data
# This analysis used temperatures for all tidal mainstem 
# Chesapeake Bay stations

temp.subset=temperatures[temperatures$month>=4&temperatures$month<=8,]
temps=c(mean(temp.subset$temp[temp.subset$year==2000]),
        mean(temp.subset$temp[temp.subset$year==2001]),
        mean(temp.subset$temp[temp.subset$year==2002]),
        mean(temp.subset$temp[temp.subset$year==2003]),
        mean(temp.subset$temp[temp.subset$year==2004]),
        mean(temp.subset$temp[temp.subset$year==2005]),
        mean(temp.subset$temp[temp.subset$year==2006]),
        mean(temp.subset$temp[temp.subset$year==2007]),
        mean(temp.subset$temp[temp.subset$year==2008]),
        mean(temp.subset$temp[temp.subset$year==2009]),
        mean(temp.subset$temp[temp.subset$year==2010]),
        mean(temp.subset$temp[temp.subset$year==2011]),
        mean(temp.subset$temp[temp.subset$year==2012]),
        mean(temp.subset$temp[temp.subset$year==2013]))

# Infection prevalence and intensity were negatively correlated 
# with annual Susquehanna River discharge for M. arenaria 
# (prevalence: coef. = -1.25E-5, t9 = -3.40, p = 0.01; 
# intensity: coef. =  -2.28E-5, t9 = -2.31, p = 0.05) 
# but not for T. plebeius (prevalence: coef. = -6.99E-6, 
# t8 = -1.60, p = 0.15; intensity: coef. = -1.17E-5, 
# t8 = -1.28, p = 0.24; Fig. 8c). Infection prevalence and 
# intensity were not correlated with spring/summer temperature 
# for M. arenaria (prevalence: coef. = 2.96E-2, t9 = -0.56, 
# p = 0.59; intensity: coef. = 6.23E-2, t9 = 0.44, p = 0.67) 
# or for T. plebeius (prevalence: coef. = -2.51E-2, t8 = -0.40, 
# p = 0.70; intensity: coef. = -9.95E-2, t8 = -0.76, p = 0.47).

summary(lm(M.int.dis~flows+temps))
# Estimate Std. Error t value Pr(>|t|)  
# (Intercept)  1.331e+00  3.082e+00   0.432   0.6760  
# flows       -2.281e-05  9.860e-06  -2.314   0.0459 *
# temps        6.227e-02  1.413e-01   0.441   0.6697  
# Multiple R-squared:  0.4176,	Adjusted R-squared:  0.2881 
# F-statistic: 3.226 on 2 and 9 DF,  p-value: 0.08783
summary(lm(T.int.dis~flows+temps))
# Estimate Std. Error t value Pr(>|t|)
# (Intercept)  4.091e+00  2.886e+00   1.417    0.194
# flows       -1.166e-05  9.128e-06  -1.277    0.237
# temps       -9.947e-02  1.317e-01  -0.756    0.472
# Multiple R-squared:  0.1849,	Adjusted R-squared:  -0.01887 
# F-statistic: 0.9074 on 2 and 8 DF,  p-value: 0.4414
summary(lm(M.prev.dis~flows+temps))
# Estimate Std. Error t value Pr(>|t|)   
# (Intercept)  1.869e+00  1.146e+00   1.631  0.13741   
# flows       -1.248e-05  3.667e-06  -3.404  0.00782 **
# temps       -2.961e-02  5.253e-02  -0.564  0.58679  
# Multiple R-squared:  0.5646,	Adjusted R-squared:  0.4679 
# F-statistic: 5.836 on 2 and 9 DF,  p-value: 0.0237
summary(lm(T.prev.dis~flows+temps))
# Estimate Std. Error t value Pr(>|t|)
# (Intercept)  1.642e+00  1.378e+00   1.192    0.268
# flows       -6.986e-06  4.358e-06  -1.603    0.148
# temps       -2.511e-02  6.285e-02  -0.399    0.700
# Multiple R-squared:  0.2432,	Adjusted R-squared:  0.05401 
# F-statistic: 1.285 on 2 and 8 DF,  p-value: 0.328


#Figure 8

cols2=c("A"="gray28","B"="white") 

txt.mya=expression(paste(italic("M. arenaria")))
txt.tag=expression(paste(italic("T. plebeius")))

summary.dis.prop=data.frame("Year"=rep(c(2000:2013),2),
                "Species"=c(rep("A",14),rep("B",14)),
                "Dis"=c(M.prev.dis,T.prev.dis),
                "se"=c(M.prev.dis.SD/sqrt(M.dis.n),T.prev.dis.SD/sqrt(T.dis.n)),
                "n"=c(M.dis.n,T.dis.n),
                "text"=c("","","","","","","","","","","","","",""," NA","","","","","","","",""," NA"," NA","","",""))
summary.dis.prop=summary.dis.prop[order(summary.dis.prop$Year,summary.dis.prop$Species),]
summary.dis.int=data.frame("Year"=rep(c(2000:2013),2),
                "Species"=c(rep("A",14),rep("B",14)),
                "Dis"=c(M.int.dis,T.int.dis),
                "se"=c(M.int.dis.SD/sqrt(M.dis.n),T.int.dis.SD/sqrt(T.dis.n)),
                "n"=c(M.dis.n,T.dis.n),
                "text"=c("","","","","","","","","","","","","",""," NA","","","","","","","",""," NA"," NA","","",""))
summary.dis.int=summary.dis.int[order(summary.dis.int$Year,summary.dis.int$Species),]

new.frame.flow=data.frame("Year"=2000:2013,"flows"=flows/100000)

jpeg("disease species.jpg", width = 7, height = 8.25,units="in",res=300)


ggplot.dis.int = ggplot(summary.dis.int, aes(x=Year, y=Dis, fill=Species)) + 
  geom_bar(position=position_dodge(), stat="identity",
           colour="black", #Use black outlines,
           size=.3) +      #Thinner lines
  geom_errorbar(aes(ymin=Dis-se, ymax=Dis+se),
                size=.3,    #Thinner lines
                width=.2,  # Width of the error bars
                position=position_dodge(.9)) +
  ylab("Intensity") +
  scale_fill_manual(name="Species",
                    values=cols2,
                    labels=c(txt.mya,txt.tag)) +
  ggtitle("") +
  geom_text(aes(x=-Inf,y=3.5,hjust=0,vjust=1,label="  a.")) +
  geom_text(data=summary.dis.int,aes(y=0,label=text),position=position_dodge(.9),vjust=0.75,hjust=0,size=4.3,angle=90) +
  scale_y_continuous(breaks=c(0.00,1.00,2.00,3.00),labels=fmt_dcimals(2)) +
  theme_cowplot() +
  theme(legend.position="none",axis.title.x=element_blank())

ggplot.dis.int = ggplot.dis.int + theme(panel.border = element_rect(fill=NA,color="black", size=1, 
                                                                    linetype="solid"))

ggplot.dis.prop = ggplot(summary.dis.prop, aes(x=Year, y=Dis, fill=Species)) + 
  geom_bar(position=position_dodge(), stat="identity",
           colour="black", #Use black outlines,
           size=.3) +      #Thinner lines
  geom_errorbar(aes(ymin=Dis-se, ymax=Dis+se),
                size=.3,    #Thinner lines
                width=.2,  # Width of the error bars
                position=position_dodge(.9)) +
  ylab("Prevalence") +
  scale_fill_manual(name="Species",
                    values=cols2,
                    labels=c(txt.mya,txt.tag)) +
  ggtitle("") +
  geom_text(aes(x=-Inf,y=1.1,hjust=0,vjust=1,label="  b.")) +
  geom_text(data=summary.dis.prop,aes(y=0,label=text),position=position_dodge(.9),vjust=0.75,hjust=0,size=4.3,angle=90) +
  scale_y_continuous(breaks=c(0.00,0.30,0.60,0.90),labels=fmt_dcimals(2)) +
  theme_cowplot() +
  theme(legend.position="none",axis.title.x=element_blank())

ggplot.dis.prop = ggplot.dis.prop + theme(panel.border = element_rect(fill=NA,color="black", size=1, 
                                           linetype="solid"))

discharge.lab=expression(paste("Discharge (x10"^"-5"," ft"^"-3"," s"^"-1",")"))

new.frame.flow[15,]=c(2013.5,NA,NA) #For spacing
ggplot.flow = ggplot(data=new.frame.flow, aes(x=Year, y=flows)) +
  geom_line(size=2) +
  xlab("Year") +
  ylab(discharge.lab) +
  scale_y_continuous(breaks=c(0.25,0.50,0.75),labels=fmt_dcimals(2)) +
  geom_text(aes(x=-Inf,y=0.75,hjust=0,vjust=1,label="  c.")) +
  theme_cowplot()

ggplot.flow = ggplot.flow + theme(panel.border = element_rect(fill=NA,color="black", size=1, 
                                           linetype="solid"))

multiplot(ggplot.dis.int, ggplot.dis.prop, ggplot.flow, cols=1)

dev.off()


####################################################

# Supplemental Figure 4

jpeg("biomass.jpg", width = 10, height = 4.5,units="in",res=300)

par(mfrow=c(1,2),mar=c(1,1,1,1))
plot(c(-77.02940,-77.02940,-75.88052,-75.88052),
     c(37.63952,36.77173,37.63952,36.77173),
     pch=19,col="white",axes=FALSE,xlab="",ylab="")
plot(cb_coastline,lwd=1,col="gray78",border="gray65",add=TRUE)
site.list.lb=loc.sites[1:13,]
site.list.lb=site.list.lb[-8,]
site.list.lb=data.frame("sites"=as.character(names(site.list.lb[,1])),
                        "lat"=unname(site.list.lb[,1]),
                        "lon"=unname(site.list.lb[,2]),
                        "M.AFDW"=rep(NA,nrow(site.list.lb)),
                        "T.AFDW"=rep(NA,nrow(site.list.lb)))
mya.lb=mya[mya$Region=="LB",]
site.lb=factor(as.character(na.omit(mya.lb$Site[mya.lb$Site!="Queen's Creek"])))
M.AFDW.lb=na.omit(mya.lb$M.AFDW)
T.AFDW.lb=na.omit(mya.lb$T.AFDW)

for(i in 1:nrow(site.list.lb)){
  site.list.lb[i,4]=round(mean(na.omit(M.AFDW.lb[site.lb==site.list.lb[i,1]])),4)
  site.list.lb[i,5]=round(mean(na.omit(T.AFDW.lb[site.lb==site.list.lb[i,1]])),4)
}
site.list.lb$lon=-1*site.list.lb$lon
site.list.lb=site.list.lb[order(site.list.lb$M.AFDW,decreasing=TRUE),]
coordinates(site.list.lb) = ~lon + lat
plot(site.list.lb,
     pch = 21,
     col="black",
     bg="gray33",
     # size the points according to the density value
     cex = site.list.lb$M.AFDW*4 + 1,
     add = TRUE)
text(txt.a,x=-76.98067,y=37.62902,cex=1.5)

plot(c(-77.02940,-77.02940,-75.88052,-75.88052),
     c(37.63952,36.77173,37.63952,36.77173),
     pch=19,col="white",axes=FALSE,xlab="",ylab="")
plot(cb_coastline,lwd=1,col="gray78",border="gray65",add=TRUE)

site.list.lb=site.list.lb[order(site.list.lb$T.AFDW,decreasing=TRUE),]
plot(site.list.lb,
     pch = 21,
     col="black",
     bg="gray33",
     # size the points according to the density value
     cex = site.list.lb$T.AFDW*4 + 1,
     add = TRUE)
text(txt.b,x=-76.98067,y=37.62902,cex=1.5)

legend(x="topright",legend=c("0.00","0.15","0.30","0.45","0.60"),
       pt.cex=c(0,0.15,0.30,0.45,0.60)*4+1,
       pch = 21,
       col="black",
       pt.bg="gray33",
       y.intersp=1.5,
       x.intersp=1,
       bty = "n",
       title="Biomass",
       cex=1.2)

dev.off()
